@@ -2,7 +2,7 @@
 #'
 #' The function is work to retrieve Publication data from UniProt for a list of proteins accessions.
 #' For more information about what included in the Publication
-#' data see https://www.uniprot.org/help/uniprotkb_column_names.
+#' data see https://www.uniprot.org/help/return_fields.
 #'
 #' @usage GetPublication(ProteinAccList , directorypath = NULL)
 #'
@@ -30,14 +30,14 @@ GetPublication <- function(ProteinAccList, directorypath = NULL)
   message("Please wait we are processing your accessions ...")
   pb <- progress::progress_bar$new(total = length(ProteinAccList))
   ProteinInfoParsed_total = data.frame()
-  baseUrl <- "http://www.uniprot.org/uniprot/"
-  Colnames = "citationmapping,citation"
+  baseUrl <- "https://rest.uniprot.org/uniprotkb/search?query=accession:"
+  columns = "lit_pubmed_id"
   for (ProteinAcc in ProteinAccList)
   {
     #to see if Request == 200 or not
     Request <- tryCatch(
       {
-        GET(paste0(baseUrl , ProteinAcc,".xml"))
+        GET(paste0(baseUrl , ProteinAcc,"&format=tsv") , timeout(7))
       },error = function(cond)
       {
         message("Internet connection problem occurs and the function will return the original error")
@@ -45,7 +45,7 @@ GetPublication <- function(ProteinAccList, directorypath = NULL)
       }
     )
     #this link return information in tab formate (format = tab)
-    ProteinName_url <- paste0("?query=accession:",ProteinAcc,"&format=tab&columns=",Colnames)
+    ProteinName_url <- paste0(ProteinAcc,"&format=tsv&fields=",columns)
     RequestUrl <- paste0(baseUrl , ProteinName_url)
     RequestUrl <- URLencode(RequestUrl)
     if (length(Request) == 0)
